scopus: Python-based API-Wrapper to access Scopus
=================================================

.. include:: installation.rst


=======
Classes
=======

scopus provides classes to interact with the various Scopus APIs (see https://dev.elsevier.com/api_docs.html):

.. currentmodule:: scopus

.. autosummary::

   ScopusAbstract
   ScopusAuthor
   ScopusSearch
   ScopusAffiliation


There is one class to provide reports:

.. autosummary::

   report


See extended description and examples below:

.. toctree::
   :maxdepth: 3

   examples


=====
Other
=====

.. toctree::
   :maxdepth: 1

   reference
   changelog
   contributing
   authors


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
